#!/bin/bash
#
# what-requires
#
# A script to do reverse requirement look-ups on a slapt-get package database
# to find out what packages require the packages listed on the command line
#
# Note that the searched for package names do not have to be installed packages,
# nor, indeed, even real packages.
#
# Note that there is no recursive look up, so this code will not give a complete or
# collated list of all of the packages requiring removal which the removal of one
# package would require.
#
# Could probably be done in a single sed script more compactly, but less accessibly.
#
# (C)  2008 M. Cathy Garrett <Cathy.Garrett@gmail.com>
#
# Released to the slapt-get-users mailing list, and generally, under the GNU GPL v.2

readonly PACKAGE_DB='/var/slapt-get/package_data'

[[ $# -eq 0 ]] && {
  echo "${0##*/}: ERROR: No packages for which to search." >&2
  exit
}

declare -i COLUMN
for PACKAGE; do [[ ${#PACKAGE} -gt $COLUMN ]] && COLUMN=${#PACKAGE}; done
COLUMN=$((COLUMN + 4))

for PACKAGE; do
# This gets everything that even mentions something similar to our target package
# its REQUIRED field.
  grep -e "^PACKAGE NAME: " -e "^PACKAGE REQUIRED: .*$PACKAGE" "$PACKAGE_DB" | \

# This narrows it down to just those named packages that legitimately have the
# target package listed in its REQUIRED field.
    egrep -B 1 -e "^PACKAGE REQUIRED: .*([[:space:]]|,)${PACKAGE//+/\+}([[:space:]]|,|$)" | \

# This only passes along the package specification for those packages.
    sed -n -e "/^PACKAGE NAME: /s/^PACKAGE NAME:[[:space:]]*//g; T; p" | \

# This part is just a pretty-print thing. Ignore it.
    xargs -n 1 printf '%s%*s%s\n' "$PACKAGE" "$((COLUMN - ${#PACKAGE}))" " "
done
